psychopy_ext.exp.Task.setup_task — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.setup_task

`Task.` `setup_task`()

  Does all the dirty setup before running the experiment.

  Steps include:
    - Logging file setup (`set_logging()`)
    - Creating a `Window` (`create_window()`)
    - Creating stimuli (`create_stimuli()`)
    - Creating trial structure (`create_trial()`)
    - Combining trials into a trial list (`create_triaList()`)
    - Creating a `TrialHandler` using the defined trialList (`create_TrialHandler()`)

  Kwargs: | create_win (bool, default: True) If False, a window is not created. This is useful when you have an experiment consisting of a couple of separate sessions. For the first one you create a window and want everything to be presented on that window without closing and reopening it between the sessions.